package main

import (
	"fmt"
	"os"
)

func main() {
	// 文件操作
	// 重命名文件
	os.Rename("b.txt", "c.txt")
	// 删除文件
	os.Remove("c.txt")

	// 文件夹操作
	// 创建文件夹（一级）
	os.Mkdir("test", 0644)
	// 创建文件夹（多级）
	err := os.MkdirAll("test/02", 0777)
	if err != nil {
		fmt.Println(err.Error())
		return
	}
	// 重命名
	os.Rename("test", "t01")
	// 删除，必须为空文件夹
	os.Remove("t01")
	// 删除文件夹下所有文件
	err = os.RemoveAll("test")
	if err != nil {
		fmt.Println(err.Error())
		return
	}

	// 文件是否存在
	file, err := os.Open("a.txt")
	if err != nil {
		fmt.Println(err.Error())
		if os.IsNotExist(err) {
			fmt.Println("no such file")
		} else if os.IsPermission(err) {
			fmt.Println("file permission error")
		}
		return
	}
	defer file.Close()

	file, err = os.Open("a.txt")
	if err != nil {
		fmt.Println(err.Error())
		if os.IsNotExist(err) {
			fmt.Println("no such file")
		} else if os.IsPermission(err) {
			fmt.Println("file permission error")
		}
		return
	}
	defer file.Close()

	// 获取文件信息 Stat Lstat
	for _, path := range []string{"a.txt", "test", "noexist"} {
		info, err := os.Stat(path)
		if err != nil {
			fmt.Println(err.Error())
			if os.IsNotExist(err) {
				fmt.Println("no such file")
			} else if os.IsPermission(err) {
				fmt.Println("file permission error")
			}
			return
		}
		fmt.Printf("%T %#v\n", info, info)
		fmt.Println(info.Name(), info.Mode(), info.IsDir(), info.ModTime(), info.Size())
	}

	// 读取文件夹下所有文件
	dir := "../"
	fileInfo, err := os.Stat(dir)
	if err != nil {
		fmt.Println(err.Error())
		return
	}

	if fileInfo.IsDir() {
		file, err := os.Open(dir)
		if err != nil {
			fmt.Println(err.Error())
			return
		}
		defer file.Close()

		fileInfos, err := file.Readdir(-1) // file.ReadDir(-1) file.Readdirnames(-1)
		if err != nil {
			return
		}
		for _, fInfo := range fileInfos {
			fmt.Printf("%T %#v\n", fInfo, fInfo)
			fmt.Println(fInfo.Name(), fInfo.IsDir(), fInfo.Size())
		}
	}
}
